package log

import (
	"fmt"
	"github.com/sirupsen/logrus"
	"os"
	"path/filepath"
	"runtime"
	"time"
)

var (
	logDir        = "/root/rosbag-handle/"
	programPrefix = "program-"
	GlobalLogger  *logrus.Logger
)

func InitLogConfig() {
	initGlobalLogger()
}

// initGlobalLogger 初始化日志配置
func initGlobalLogger() {
	time.Sleep(time.Duration(1) * time.Second)
	// 创建、追加、读写，777，所有权限
	f, err := os.OpenFile(logDir+programPrefix+time.Now().Format("2006-01-02-15-04-05")+".log", os.O_CREATE|os.O_APPEND|os.O_RDWR, os.ModePerm)
	if err != nil {
		os.Exit(-1)
	} else {
		GlobalLogger = logrus.New()
		GlobalLogger.SetOutput(f)
		GlobalLogger.SetReportCaller(true)
		GlobalLogger.SetFormatter(&logrus.JSONFormatter{
			CallerPrettyfier: func(frame *runtime.Frame) (string, string) {
				return "", fmt.Sprintf("%s:%d", filepath.Base(frame.File), frame.Line)
			},
		})
		GlobalLogger.Info("初始化GlobalLogger - 成功")
	}
}
